# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: missionResponse.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='missionResponse.proto',
  package='colav',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x15missionResponse.proto\x12\x05\x63olav\"\x80\x03\n\x0fMissionResponse\x12\x0b\n\x03tag\x18\x01 \x01(\t\x12+\n\x05stamp\x18\x02 \x01(\x0b\x32\x1c.colav.MissionResponse.Stamp\x12;\n\x08response\x18\x03 \x01(\x0b\x32).colav.MissionResponse.MissionResponseMsg\x1a%\n\x05Stamp\x12\x0b\n\x03sec\x18\x01 \x01(\r\x12\x0f\n\x07nanosec\x18\x02 \x01(\r\x1a\xce\x01\n\x12MissionResponseMsg\x12H\n\x04type\x18\x01 \x01(\x0e\x32:.colav.MissionResponse.MissionResponseMsg.ResponseTypeEnum\x12\x0f\n\x07\x64\x65tails\x18\x02 \x01(\t\"]\n\x10ResponseTypeEnum\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x14\n\x10MISSION_STARTING\x10\x01\x12\x11\n\rMISSION_ERROR\x10\x02\x12\x13\n\x0fMISSION_INVALID\x10\x03\x62\x06proto3'
)



_MISSIONRESPONSE_MISSIONRESPONSEMSG_RESPONSETYPEENUM = _descriptor.EnumDescriptor(
  name='ResponseTypeEnum',
  full_name='colav.MissionResponse.MissionResponseMsg.ResponseTypeEnum',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MISSION_STARTING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MISSION_ERROR', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MISSION_INVALID', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=324,
  serialized_end=417,
)
_sym_db.RegisterEnumDescriptor(_MISSIONRESPONSE_MISSIONRESPONSEMSG_RESPONSETYPEENUM)


_MISSIONRESPONSE_STAMP = _descriptor.Descriptor(
  name='Stamp',
  full_name='colav.MissionResponse.Stamp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sec', full_name='colav.MissionResponse.Stamp.sec', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nanosec', full_name='colav.MissionResponse.Stamp.nanosec', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=171,
  serialized_end=208,
)

_MISSIONRESPONSE_MISSIONRESPONSEMSG = _descriptor.Descriptor(
  name='MissionResponseMsg',
  full_name='colav.MissionResponse.MissionResponseMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='colav.MissionResponse.MissionResponseMsg.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='details', full_name='colav.MissionResponse.MissionResponseMsg.details', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MISSIONRESPONSE_MISSIONRESPONSEMSG_RESPONSETYPEENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=211,
  serialized_end=417,
)

_MISSIONRESPONSE = _descriptor.Descriptor(
  name='MissionResponse',
  full_name='colav.MissionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tag', full_name='colav.MissionResponse.tag', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stamp', full_name='colav.MissionResponse.stamp', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response', full_name='colav.MissionResponse.response', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MISSIONRESPONSE_STAMP, _MISSIONRESPONSE_MISSIONRESPONSEMSG, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33,
  serialized_end=417,
)

_MISSIONRESPONSE_STAMP.containing_type = _MISSIONRESPONSE
_MISSIONRESPONSE_MISSIONRESPONSEMSG.fields_by_name['type'].enum_type = _MISSIONRESPONSE_MISSIONRESPONSEMSG_RESPONSETYPEENUM
_MISSIONRESPONSE_MISSIONRESPONSEMSG.containing_type = _MISSIONRESPONSE
_MISSIONRESPONSE_MISSIONRESPONSEMSG_RESPONSETYPEENUM.containing_type = _MISSIONRESPONSE_MISSIONRESPONSEMSG
_MISSIONRESPONSE.fields_by_name['stamp'].message_type = _MISSIONRESPONSE_STAMP
_MISSIONRESPONSE.fields_by_name['response'].message_type = _MISSIONRESPONSE_MISSIONRESPONSEMSG
DESCRIPTOR.message_types_by_name['MissionResponse'] = _MISSIONRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MissionResponse = _reflection.GeneratedProtocolMessageType('MissionResponse', (_message.Message,), {

  'Stamp' : _reflection.GeneratedProtocolMessageType('Stamp', (_message.Message,), {
    'DESCRIPTOR' : _MISSIONRESPONSE_STAMP,
    '__module__' : 'missionResponse_pb2'
    # @@protoc_insertion_point(class_scope:colav.MissionResponse.Stamp)
    })
  ,

  'MissionResponseMsg' : _reflection.GeneratedProtocolMessageType('MissionResponseMsg', (_message.Message,), {
    'DESCRIPTOR' : _MISSIONRESPONSE_MISSIONRESPONSEMSG,
    '__module__' : 'missionResponse_pb2'
    # @@protoc_insertion_point(class_scope:colav.MissionResponse.MissionResponseMsg)
    })
  ,
  'DESCRIPTOR' : _MISSIONRESPONSE,
  '__module__' : 'missionResponse_pb2'
  # @@protoc_insertion_point(class_scope:colav.MissionResponse)
  })
_sym_db.RegisterMessage(MissionResponse)
_sym_db.RegisterMessage(MissionResponse.Stamp)
_sym_db.RegisterMessage(MissionResponse.MissionResponseMsg)


# @@protoc_insertion_point(module_scope)
