# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: unsafeSet.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor.FileDescriptor(
    name="unsafeSet.proto",
    package="colav",
    syntax="proto3",
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n\x0funsafeSet.proto\x12\x05\x63olav"\xcc\x01\n\tUnsafeSet\x12%\n\x05stamp\x18\x01 \x01(\x0b\x32\x16.colav.UnsafeSet.Stamp\x12\x13\n\x0bmission_tag\x18\x02 \x01(\t\x12-\n\x08vertices\x18\x03 \x03(\x0b\x32\x1b.colav.UnsafeSet.Coordinate\x1a%\n\x05Stamp\x12\x0b\n\x03sec\x18\x01 \x01(\r\x12\x0f\n\x07nanosec\x18\x02 \x01(\r\x1a-\n\nCoordinate\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\t\n\x01z\x18\x03 \x01(\x02\x62\x06proto3',
)


_UNSAFESET_STAMP = _descriptor.Descriptor(
    name="Stamp",
    full_name="colav.UnsafeSet.Stamp",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="sec",
            full_name="colav.UnsafeSet.Stamp.sec",
            index=0,
            number=1,
            type=13,
            cpp_type=3,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="nanosec",
            full_name="colav.UnsafeSet.Stamp.nanosec",
            index=1,
            number=2,
            type=13,
            cpp_type=3,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=147,
    serialized_end=184,
)

_UNSAFESET_COORDINATE = _descriptor.Descriptor(
    name="Coordinate",
    full_name="colav.UnsafeSet.Coordinate",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="x",
            full_name="colav.UnsafeSet.Coordinate.x",
            index=0,
            number=1,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="y",
            full_name="colav.UnsafeSet.Coordinate.y",
            index=1,
            number=2,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="z",
            full_name="colav.UnsafeSet.Coordinate.z",
            index=2,
            number=3,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=186,
    serialized_end=231,
)

_UNSAFESET = _descriptor.Descriptor(
    name="UnsafeSet",
    full_name="colav.UnsafeSet",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="stamp",
            full_name="colav.UnsafeSet.stamp",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="mission_tag",
            full_name="colav.UnsafeSet.mission_tag",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="vertices",
            full_name="colav.UnsafeSet.vertices",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[
        _UNSAFESET_STAMP,
        _UNSAFESET_COORDINATE,
    ],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=27,
    serialized_end=231,
)

_UNSAFESET_STAMP.containing_type = _UNSAFESET
_UNSAFESET_COORDINATE.containing_type = _UNSAFESET
_UNSAFESET.fields_by_name["stamp"].message_type = _UNSAFESET_STAMP
_UNSAFESET.fields_by_name["vertices"].message_type = _UNSAFESET_COORDINATE
DESCRIPTOR.message_types_by_name["UnsafeSet"] = _UNSAFESET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UnsafeSet = _reflection.GeneratedProtocolMessageType(
    "UnsafeSet",
    (_message.Message,),
    {
        "Stamp": _reflection.GeneratedProtocolMessageType(
            "Stamp",
            (_message.Message,),
            {
                "DESCRIPTOR": _UNSAFESET_STAMP,
                "__module__": "unsafeSet_pb2",
                # @@protoc_insertion_point(class_scope:colav.UnsafeSet.Stamp)
            },
        ),
        "Coordinate": _reflection.GeneratedProtocolMessageType(
            "Coordinate",
            (_message.Message,),
            {
                "DESCRIPTOR": _UNSAFESET_COORDINATE,
                "__module__": "unsafeSet_pb2",
                # @@protoc_insertion_point(class_scope:colav.UnsafeSet.Coordinate)
            },
        ),
        "DESCRIPTOR": _UNSAFESET,
        "__module__": "unsafeSet_pb2",
        # @@protoc_insertion_point(class_scope:colav.UnsafeSet)
    },
)
_sym_db.RegisterMessage(UnsafeSet)
_sym_db.RegisterMessage(UnsafeSet.Stamp)
_sym_db.RegisterMessage(UnsafeSet.Coordinate)


# @@protoc_insertion_point(module_scope)
