# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: controllerFeedback.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='controllerFeedback.proto',
  package='colav',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x18\x63ontrollerFeedback.proto\x12\x05\x63olav\"\x80\x04\n\x12\x43ontrollerFeedback\x12\x13\n\x0bmission_tag\x18\x01 \x01(\t\x12\x11\n\tagent_tag\x18\x02 \x01(\t\x12\x30\n\x04mode\x18\x03 \x01(\x0e\x32\".colav.ControllerFeedback.CtrlMode\x12\x34\n\x06status\x18\x04 \x01(\x0e\x32$.colav.ControllerFeedback.CtrlStatus\x12\x30\n\x03\x63md\x18\x05 \x01(\x0b\x32#.colav.ControllerFeedback.CmdVelYaw\x12.\n\x05stamp\x18\x06 \x01(\x0b\x32\x1f.colav.ControllerFeedback.Stamp\x1a/\n\tCmdVelYaw\x12\x10\n\x08velocity\x18\x01 \x01(\x02\x12\x10\n\x08yaw_rate\x18\x02 \x01(\x02\x1a%\n\x05Stamp\x12\x0b\n\x03sec\x18\x01 \x01(\r\x12\x0f\n\x07nanosec\x18\x02 \x01(\r\"Y\n\x08\x43trlMode\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06\x43RUISE\x10\x01\x12\t\n\x05T2LOS\x10\x02\x12\x0b\n\x07T2Theta\x10\x03\x12\x06\n\x02\x46\x42\x10\x04\x12\x14\n\x10WAYPOINT_REACHED\x10\x05\"E\n\nCtrlStatus\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\x12\x0c\n\x08INACTIVE\x10\x02\x12\t\n\x05\x45RROR\x10\x03\x62\x06proto3'
)



_CONTROLLERFEEDBACK_CTRLMODE = _descriptor.EnumDescriptor(
  name='CtrlMode',
  full_name='colav.ControllerFeedback.CtrlMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CRUISE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='T2LOS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='T2Theta', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FB', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WAYPOINT_REACHED', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=388,
  serialized_end=477,
)
_sym_db.RegisterEnumDescriptor(_CONTROLLERFEEDBACK_CTRLMODE)

_CONTROLLERFEEDBACK_CTRLSTATUS = _descriptor.EnumDescriptor(
  name='CtrlStatus',
  full_name='colav.ControllerFeedback.CtrlStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_STATUS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTIVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INACTIVE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=479,
  serialized_end=548,
)
_sym_db.RegisterEnumDescriptor(_CONTROLLERFEEDBACK_CTRLSTATUS)


_CONTROLLERFEEDBACK_CMDVELYAW = _descriptor.Descriptor(
  name='CmdVelYaw',
  full_name='colav.ControllerFeedback.CmdVelYaw',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='velocity', full_name='colav.ControllerFeedback.CmdVelYaw.velocity', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaw_rate', full_name='colav.ControllerFeedback.CmdVelYaw.yaw_rate', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=300,
  serialized_end=347,
)

_CONTROLLERFEEDBACK_STAMP = _descriptor.Descriptor(
  name='Stamp',
  full_name='colav.ControllerFeedback.Stamp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sec', full_name='colav.ControllerFeedback.Stamp.sec', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nanosec', full_name='colav.ControllerFeedback.Stamp.nanosec', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=349,
  serialized_end=386,
)

_CONTROLLERFEEDBACK = _descriptor.Descriptor(
  name='ControllerFeedback',
  full_name='colav.ControllerFeedback',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mission_tag', full_name='colav.ControllerFeedback.mission_tag', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='agent_tag', full_name='colav.ControllerFeedback.agent_tag', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mode', full_name='colav.ControllerFeedback.mode', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='colav.ControllerFeedback.status', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cmd', full_name='colav.ControllerFeedback.cmd', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stamp', full_name='colav.ControllerFeedback.stamp', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CONTROLLERFEEDBACK_CMDVELYAW, _CONTROLLERFEEDBACK_STAMP, ],
  enum_types=[
    _CONTROLLERFEEDBACK_CTRLMODE,
    _CONTROLLERFEEDBACK_CTRLSTATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=36,
  serialized_end=548,
)

_CONTROLLERFEEDBACK_CMDVELYAW.containing_type = _CONTROLLERFEEDBACK
_CONTROLLERFEEDBACK_STAMP.containing_type = _CONTROLLERFEEDBACK
_CONTROLLERFEEDBACK.fields_by_name['mode'].enum_type = _CONTROLLERFEEDBACK_CTRLMODE
_CONTROLLERFEEDBACK.fields_by_name['status'].enum_type = _CONTROLLERFEEDBACK_CTRLSTATUS
_CONTROLLERFEEDBACK.fields_by_name['cmd'].message_type = _CONTROLLERFEEDBACK_CMDVELYAW
_CONTROLLERFEEDBACK.fields_by_name['stamp'].message_type = _CONTROLLERFEEDBACK_STAMP
_CONTROLLERFEEDBACK_CTRLMODE.containing_type = _CONTROLLERFEEDBACK
_CONTROLLERFEEDBACK_CTRLSTATUS.containing_type = _CONTROLLERFEEDBACK
DESCRIPTOR.message_types_by_name['ControllerFeedback'] = _CONTROLLERFEEDBACK
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ControllerFeedback = _reflection.GeneratedProtocolMessageType('ControllerFeedback', (_message.Message,), {

  'CmdVelYaw' : _reflection.GeneratedProtocolMessageType('CmdVelYaw', (_message.Message,), {
    'DESCRIPTOR' : _CONTROLLERFEEDBACK_CMDVELYAW,
    '__module__' : 'controllerFeedback_pb2'
    # @@protoc_insertion_point(class_scope:colav.ControllerFeedback.CmdVelYaw)
    })
  ,

  'Stamp' : _reflection.GeneratedProtocolMessageType('Stamp', (_message.Message,), {
    'DESCRIPTOR' : _CONTROLLERFEEDBACK_STAMP,
    '__module__' : 'controllerFeedback_pb2'
    # @@protoc_insertion_point(class_scope:colav.ControllerFeedback.Stamp)
    })
  ,
  'DESCRIPTOR' : _CONTROLLERFEEDBACK,
  '__module__' : 'controllerFeedback_pb2'
  # @@protoc_insertion_point(class_scope:colav.ControllerFeedback)
  })
_sym_db.RegisterMessage(ControllerFeedback)
_sym_db.RegisterMessage(ControllerFeedback.CmdVelYaw)
_sym_db.RegisterMessage(ControllerFeedback.Stamp)


# @@protoc_insertion_point(module_scope)
