# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: missionRequest.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='missionRequest.proto',
  package='colav',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x14missionRequest.proto\x12\x05\x63olav\"\xee\x06\n\x0eMissionRequest\x12\x0b\n\x03tag\x18\x01 \x01(\t\x12*\n\x05stamp\x18\x02 \x01(\x0b\x32\x1b.colav.MissionRequest.Stamp\x12,\n\x06vessel\x18\x03 \x01(\x0b\x32\x1c.colav.MissionRequest.Vessel\x12\x32\n\rinit_position\x18\x04 \x01(\x0b\x32\x1b.colav.MissionRequest.Point\x12:\n\x0egoal_waypoints\x18\x05 \x03(\x0b\x32\".colav.MissionRequest.GoalWaypoint\x1a%\n\x05Stamp\x12\x0b\n\x03sec\x18\x01 \x01(\r\x12\x0f\n\x07nanosec\x18\x02 \x01(\r\x1a(\n\x05Point\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\t\n\x01z\x18\x03 \x01(\x02\x1a\xd9\x03\n\x06Vessel\x12\x0b\n\x03tag\x18\x01 \x01(\t\x12\x35\n\x04type\x18\x02 \x01(\x0e\x32\'.colav.MissionRequest.Vessel.VesselType\x12\x43\n\x0b\x63onstraints\x18\x03 \x01(\x0b\x32..colav.MissionRequest.Vessel.VesselConstraints\x12=\n\x08geometry\x18\x04 \x01(\x0b\x32+.colav.MissionRequest.Vessel.VesselGeometry\x1a\x89\x01\n\x11VesselConstraints\x12\x18\n\x10max_acceleration\x18\x03 \x01(\x02\x12\x18\n\x10max_deceleration\x18\x04 \x01(\x02\x12\x14\n\x0cmax_velocity\x18\x05 \x01(\x02\x12\x14\n\x0cmin_velocity\x18\x06 \x01(\x02\x12\x14\n\x0cmax_yaw_rate\x18\x07 \x01(\x02\x1a\x42\n\x0eVesselGeometry\x12\x0b\n\x03loa\x18\x01 \x01(\x02\x12\x0c\n\x04\x62\x65\x61m\x18\x02 \x01(\x02\x12\x15\n\rsafety_radius\x18\x03 \x01(\x02\"7\n\nVesselType\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\r\n\tHYDROFOIL\x10\x01\x12\t\n\x05OTHER\x10\x02\x1aX\n\x0cGoalWaypoint\x12-\n\x08position\x18\x01 \x01(\x0b\x32\x1b.colav.MissionRequest.Point\x12\x19\n\x11\x61\x63\x63\x65ptance_radius\x18\x02 \x01(\x02\x62\x06proto3'
)



_MISSIONREQUEST_VESSEL_VESSELTYPE = _descriptor.EnumDescriptor(
  name='VesselType',
  full_name='colav.MissionRequest.Vessel.VesselType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HYDROFOIL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OTHER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=765,
  serialized_end=820,
)
_sym_db.RegisterEnumDescriptor(_MISSIONREQUEST_VESSEL_VESSELTYPE)


_MISSIONREQUEST_STAMP = _descriptor.Descriptor(
  name='Stamp',
  full_name='colav.MissionRequest.Stamp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sec', full_name='colav.MissionRequest.Stamp.sec', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nanosec', full_name='colav.MissionRequest.Stamp.nanosec', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=265,
  serialized_end=302,
)

_MISSIONREQUEST_POINT = _descriptor.Descriptor(
  name='Point',
  full_name='colav.MissionRequest.Point',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='colav.MissionRequest.Point.x', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='colav.MissionRequest.Point.y', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='z', full_name='colav.MissionRequest.Point.z', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=304,
  serialized_end=344,
)

_MISSIONREQUEST_VESSEL_VESSELCONSTRAINTS = _descriptor.Descriptor(
  name='VesselConstraints',
  full_name='colav.MissionRequest.Vessel.VesselConstraints',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_acceleration', full_name='colav.MissionRequest.Vessel.VesselConstraints.max_acceleration', index=0,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_deceleration', full_name='colav.MissionRequest.Vessel.VesselConstraints.max_deceleration', index=1,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_velocity', full_name='colav.MissionRequest.Vessel.VesselConstraints.max_velocity', index=2,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_velocity', full_name='colav.MissionRequest.Vessel.VesselConstraints.min_velocity', index=3,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_yaw_rate', full_name='colav.MissionRequest.Vessel.VesselConstraints.max_yaw_rate', index=4,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=558,
  serialized_end=695,
)

_MISSIONREQUEST_VESSEL_VESSELGEOMETRY = _descriptor.Descriptor(
  name='VesselGeometry',
  full_name='colav.MissionRequest.Vessel.VesselGeometry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='loa', full_name='colav.MissionRequest.Vessel.VesselGeometry.loa', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='beam', full_name='colav.MissionRequest.Vessel.VesselGeometry.beam', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='safety_radius', full_name='colav.MissionRequest.Vessel.VesselGeometry.safety_radius', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=697,
  serialized_end=763,
)

_MISSIONREQUEST_VESSEL = _descriptor.Descriptor(
  name='Vessel',
  full_name='colav.MissionRequest.Vessel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tag', full_name='colav.MissionRequest.Vessel.tag', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='colav.MissionRequest.Vessel.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='constraints', full_name='colav.MissionRequest.Vessel.constraints', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='geometry', full_name='colav.MissionRequest.Vessel.geometry', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MISSIONREQUEST_VESSEL_VESSELCONSTRAINTS, _MISSIONREQUEST_VESSEL_VESSELGEOMETRY, ],
  enum_types=[
    _MISSIONREQUEST_VESSEL_VESSELTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=347,
  serialized_end=820,
)

_MISSIONREQUEST_GOALWAYPOINT = _descriptor.Descriptor(
  name='GoalWaypoint',
  full_name='colav.MissionRequest.GoalWaypoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='position', full_name='colav.MissionRequest.GoalWaypoint.position', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acceptance_radius', full_name='colav.MissionRequest.GoalWaypoint.acceptance_radius', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=822,
  serialized_end=910,
)

_MISSIONREQUEST = _descriptor.Descriptor(
  name='MissionRequest',
  full_name='colav.MissionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tag', full_name='colav.MissionRequest.tag', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stamp', full_name='colav.MissionRequest.stamp', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vessel', full_name='colav.MissionRequest.vessel', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='init_position', full_name='colav.MissionRequest.init_position', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='goal_waypoints', full_name='colav.MissionRequest.goal_waypoints', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MISSIONREQUEST_STAMP, _MISSIONREQUEST_POINT, _MISSIONREQUEST_VESSEL, _MISSIONREQUEST_GOALWAYPOINT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32,
  serialized_end=910,
)

_MISSIONREQUEST_STAMP.containing_type = _MISSIONREQUEST
_MISSIONREQUEST_POINT.containing_type = _MISSIONREQUEST
_MISSIONREQUEST_VESSEL_VESSELCONSTRAINTS.containing_type = _MISSIONREQUEST_VESSEL
_MISSIONREQUEST_VESSEL_VESSELGEOMETRY.containing_type = _MISSIONREQUEST_VESSEL
_MISSIONREQUEST_VESSEL.fields_by_name['type'].enum_type = _MISSIONREQUEST_VESSEL_VESSELTYPE
_MISSIONREQUEST_VESSEL.fields_by_name['constraints'].message_type = _MISSIONREQUEST_VESSEL_VESSELCONSTRAINTS
_MISSIONREQUEST_VESSEL.fields_by_name['geometry'].message_type = _MISSIONREQUEST_VESSEL_VESSELGEOMETRY
_MISSIONREQUEST_VESSEL.containing_type = _MISSIONREQUEST
_MISSIONREQUEST_VESSEL_VESSELTYPE.containing_type = _MISSIONREQUEST_VESSEL
_MISSIONREQUEST_GOALWAYPOINT.fields_by_name['position'].message_type = _MISSIONREQUEST_POINT
_MISSIONREQUEST_GOALWAYPOINT.containing_type = _MISSIONREQUEST
_MISSIONREQUEST.fields_by_name['stamp'].message_type = _MISSIONREQUEST_STAMP
_MISSIONREQUEST.fields_by_name['vessel'].message_type = _MISSIONREQUEST_VESSEL
_MISSIONREQUEST.fields_by_name['init_position'].message_type = _MISSIONREQUEST_POINT
_MISSIONREQUEST.fields_by_name['goal_waypoints'].message_type = _MISSIONREQUEST_GOALWAYPOINT
DESCRIPTOR.message_types_by_name['MissionRequest'] = _MISSIONREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MissionRequest = _reflection.GeneratedProtocolMessageType('MissionRequest', (_message.Message,), {

  'Stamp' : _reflection.GeneratedProtocolMessageType('Stamp', (_message.Message,), {
    'DESCRIPTOR' : _MISSIONREQUEST_STAMP,
    '__module__' : 'missionRequest_pb2'
    # @@protoc_insertion_point(class_scope:colav.MissionRequest.Stamp)
    })
  ,

  'Point' : _reflection.GeneratedProtocolMessageType('Point', (_message.Message,), {
    'DESCRIPTOR' : _MISSIONREQUEST_POINT,
    '__module__' : 'missionRequest_pb2'
    # @@protoc_insertion_point(class_scope:colav.MissionRequest.Point)
    })
  ,

  'Vessel' : _reflection.GeneratedProtocolMessageType('Vessel', (_message.Message,), {

    'VesselConstraints' : _reflection.GeneratedProtocolMessageType('VesselConstraints', (_message.Message,), {
      'DESCRIPTOR' : _MISSIONREQUEST_VESSEL_VESSELCONSTRAINTS,
      '__module__' : 'missionRequest_pb2'
      # @@protoc_insertion_point(class_scope:colav.MissionRequest.Vessel.VesselConstraints)
      })
    ,

    'VesselGeometry' : _reflection.GeneratedProtocolMessageType('VesselGeometry', (_message.Message,), {
      'DESCRIPTOR' : _MISSIONREQUEST_VESSEL_VESSELGEOMETRY,
      '__module__' : 'missionRequest_pb2'
      # @@protoc_insertion_point(class_scope:colav.MissionRequest.Vessel.VesselGeometry)
      })
    ,
    'DESCRIPTOR' : _MISSIONREQUEST_VESSEL,
    '__module__' : 'missionRequest_pb2'
    # @@protoc_insertion_point(class_scope:colav.MissionRequest.Vessel)
    })
  ,

  'GoalWaypoint' : _reflection.GeneratedProtocolMessageType('GoalWaypoint', (_message.Message,), {
    'DESCRIPTOR' : _MISSIONREQUEST_GOALWAYPOINT,
    '__module__' : 'missionRequest_pb2'
    # @@protoc_insertion_point(class_scope:colav.MissionRequest.GoalWaypoint)
    })
  ,
  'DESCRIPTOR' : _MISSIONREQUEST,
  '__module__' : 'missionRequest_pb2'
  # @@protoc_insertion_point(class_scope:colav.MissionRequest)
  })
_sym_db.RegisterMessage(MissionRequest)
_sym_db.RegisterMessage(MissionRequest.Stamp)
_sym_db.RegisterMessage(MissionRequest.Point)
_sym_db.RegisterMessage(MissionRequest.Vessel)
_sym_db.RegisterMessage(MissionRequest.Vessel.VesselConstraints)
_sym_db.RegisterMessage(MissionRequest.Vessel.VesselGeometry)
_sym_db.RegisterMessage(MissionRequest.GoalWaypoint)


# @@protoc_insertion_point(module_scope)
